@@ -2,7 +2,7 @@
 ##
 ## pyChing -- a Python program to cast and interpret I Ching hexagrams
 ##
-## Copyright (C) 1999,2000 Stephen M. Gava
+## Copyright (C) 1999-2006 Stephen M. Gava
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -63,9 +63,9 @@ def hlIntroData():
 <html><body><p>
 <h2>Introduction to the I Ching</h2>
 <p>
-Following is an extremely brief introduction to what the I Ching actually is, after which is a quick explanation of the coin method used by pyChing to perform its readings, a quick note on wording, and pointers to a couple of books where you would be able to obtain more useful information on the I Ching and the related philosophy of Taoism. I don't claim to be an expert on the subject(s) myself.
+Following is an extremely brief introduction to what the I Ching actually is, after which is a quick explanation of the coin method used by pyChing to perform its readings, a quick note on wording, and pointers to a couple of books where you would be able to obtain more useful information on the I Ching and the related philosophy of Taoism.
 <p>
-The I Ching, or Book Of Changes, is an ancient Chinese book (its origins date back perhaps 5,000 years) that has been used since time immemorial  as a source of wisdom or advice in dealing with life's complexities. 
+The I Ching, or Book Of Changes, is an ancient Chinese book (its origins date back perhaps 5,000 years) that has been used since time immemorial as a source of wisdom or advice in dealing with life's complexities. 
 <p>
 The book can simply be read or browsed to glean insight or inspiration,  but it is also commonly consulted as an oracle, by formulating a question  and using some means of harnessing chance (or more interestingly,  synchronicity, as described by Carl Jung in his foreword to the Wilhelm  translation [see below]) to build one or two 'hexgrams' (figures  constructed from six lines), which are meant to be keys to the heart of  the underlying issues surrounding the question asked. 
 <p>
@@ -77,25 +77,25 @@ The coin oracle, the method used by pyChing to perform I Ching readings, is brie
 <p>
 <h3>The Coin Oracle</h3>
 <p>
-This method of casting I Ching hexagrams involes the use of three coins, which are tossed simultaneously six times, with each toss of the coins rendering one of the hexagram's six lines. Afficianados of this method often prefer to employ old Chinese coins with a square hole in the middle and an inscription on one side. With this type of coin the inscribed side generally represents Yin (passive, fecund, shadow energy) with a value of 2, while the other side represents Yang (creative, active, light energy) with a value of 3. (If you happen to use any other kind of coins to perform a reading just decide in advance which side represents Yin and which represents Yang, tails for Yin and heads for Yang might be a good choice.)
+This method of casting I Ching hexagrams involes the use of three coins, which are tossed simultaneously six times, with each toss of the coins rendering one of the hexagram's six lines. Afficianados of this method often prefer to employ old Chinese coins with a square hole in the middle and an inscription on one side. With this type of coin the inscribed side generally represents Yin (passive, fecund, shadow energy) with a value of 2, while the other side represents Yang (creative, active, light energy) with a value of 3. If you happen to use any other kind of coins to perform a reading just decide in advance which side represents Yin and which represents Yang (tails for Yin and heads for Yang might be a good choice).
 <p>
 The values of the three thrown coins are added together to give the value for that line. Each of the four possible line values (6,7,8 or 9)  indicates a particular type of line to be drawn in building the first  hexagram, as follows:
 <p>
-&nbsp<b>6</b>&nbsp&nbsp  represents a moving (old) Yin line, which is drawn as: 
-      <pre>   ---- X ----</pre>   
-   (a line with a gap that has a cross in it)<p>
-   
-&nbsp<b>7</b>&nbsp&nbsp  represents a static (young) Yang line, which is drawn as: 
-      <pre>   -----------</pre>
-   (a line with no gap)<p>     
+<b>6</b>,  represents a moving (old) Yin line, which is drawn as: 
+            <pre>   ---- X ----</pre>   
+     (a line with a gap that has a cross in it)<p>
+     
+<b>7</b>,  represents a static (young) Yang line, which is drawn as: 
+            <pre>   -----------</pre>
+     (a line with no gap)<p>     
 
-&nbsp<b>8</b>&nbsp&nbsp  represents a static (young) Yin line, which is drawn as: 
-      <pre>   ----   ----</pre>
-   (a line with a gap in the middle)<p>     
+<b>8</b>,  represents a static (young) Yin line, which is drawn as: 
+            <pre>   ----   ----</pre>
+     (a line with a gap in the middle)<p>     
 
-&nbsp<b>9</b>&nbsp&nbsp  represents a moving (old) Yang line, which is drawn as: 
-      <pre>   -----O-----</pre>
-   (a line with no gap with a circle in the middle)<p>
+<b>9</b>,  represents a moving (old) Yang line, which is drawn as: 
+            <pre>   -----O-----</pre>
+     (a line with no gap with a circle in the middle)<p>
 
 The hexagram is built from the bottom upwards. 
 <p>
@@ -107,23 +107,23 @@ The casting of the hexagram(s) is now complete, and you can look up the sections
 <p>
 <b>Hexagram Names</b>
 <p>
-Firstly I should note here that the names of the hexgrams as presented in pyChing may vary from any books on the subject you consult (although of  course the numbers are always the same). There are several systems for  attempting to render Chinese words into pronounceable english (and in fact, if you read more than one translation of the I Ching you will find the names spelt in many different ways, but they should always sound pretty much the same when you say them), apart from the one I have followed here.
+Firstly I should note here that the names of the hexgrams as presented in pyChing may vary from any books on the subject you consult (although of  course the hexagram numbers are always the same). There are several systems for  attempting to render Chinese words into pronounceable english (and in fact, if you read more than one translation of the I Ching you will find the names spelt in many different ways, but they should always sound pretty much the same when you say them), apart from the one I have followed here.
 <p>
 <b>Hexagram Information</b>
 <p>
-The information (interpretation) of the hexagrams presented in pyChing is couched in the usual flowery language that results from attempts to translate extremely terse and ancient Chinese into western languages. (If you read any of the full translations available you will find that the various translators have found lots of scope for variation on the theme of the undelying phrases also, although the bones remain the same.) This can lead to some problems in dealing with some of the recurring motifs in the text.
+The information on (interpretation of) the hexagrams presented in pyChing is couched in the usual flowery language that results from attempts to translate extremely terse and ancient Chinese into western languages. (If you read any of the full translations available you will find that the various translators have found lots of scope for variation on the theme of the undelying phrases also, although the bones always remain the same.) This can lead to some problems in dealing with some of the recurring motifs in the text.
 <p>
 If you find all the 'he' and 'the superior man' stuff you might read in  some translations a tad sexist, remember that these gender specific  pronouns are inserted by the translators in order to make sentences which  scan better in western-style languages. The original language is said to  be formed of such extremely terse and compact imagery that it barely contains any pronoun-like elements at all. So if these constructs bother you feel free to substitute 'she' or 'the superior woman' to your heart's content.
 <p>
 On the subject of phrases like 'the sage', 'the superior man', or 'the  superior person', it may be useful to think of them as indicatiing someone who has attained some degree of wisdom, ie, the position you may  be aspiring to. 
 <p>
-Lastly, let me just say that if all the talk about 'heaven' bothers you,  you can think of the idea the translators have tried to convey with that  word as representing 'the cosmic oneness' or 'the universe' or 'the way of things' or whatever else makes sense in your personal mythology.
+Lastly, let me just say that if all the talk about 'heaven' bothers you,  you can think of the idea the translators have tried to convey with that  word as representing 'the cosmic oneness' or 'the essence of the universe' or 'the underlying way of things' or whatever else makes sense in your personal mythology.
 <p>
-The main point is, read the imagery, and go with whatever ideas related to your question you find arising in your mind, trust the angle that makes  sense to you or feels right to you.
+The main point is, read the imagery, and go with whatever ideas related to your question you find arising in your mind, trust the angle that makes  sense to you or feels right to you!
 <p>
 <h3>Further Reading</h3>
 <p>
-There have been many translations of the I Ching, and many books written on the subject and on the related subject of Taoism, a philosophy that embraces the underlying principle of change expressed in the I Ching and the notion of accepting change and becoming attuned to 'the way things are going'.
+There have been many translations of the I Ching, and many books written on the subject and on the related subject of Taoism, a philosophy that embraces the underlying principle of change expressed in the I Ching and the notion of accepting change and becoming attuned to 'the way things are really going'.
 <p>
 Many libraries and bookstores will have titles on these subjects in their philosophy or religion or 'new age' sections. So if you're interested why not seek something out yourself from one of these sources?
 <p>
@@ -195,6 +195,8 @@ Here follows a brief description of the actions performed by each menu choice in
 <p>
 <b>Introduction to the I Ching</b> -  Displays a brief introduction to the I Ching itself.
 <p>
+<b>Browse Hexagram Information</b> -  Allows you to browse the available information on each hexagram.
+<p>
 <b>About pyChing</b> -  Shows pyChing's About box. License details and program credits can also be viewed from the About box.
 <p></body></html>
 """
@@ -250,10 +252,13 @@ Displays some information about the version of pyChing you are running. This dia
 <p> 
 <b>Ok</b>  -  Click this when you're finished with the About box.
 <p>
-Note that the pyChing version number has three segments, x.y.z . The middle section of the version number (y), indicates whether the version is a stable (release) version, or an unstable (development, or beta) version. Stable versions have an even number for their middle (y) section, unstable versions have an odd number there. Stable versions should hopefully have less show stopping bugs and less incomplete features, because they've been tested a little more on some platforms. Most testing of pyChing takes place on Linux, so if you run it on some other platform I'd particularly  like to know how it goes, or get any detailed bug reports. Contact details  are shown in the About box.  
+The pyChing version number will have 'beta' added to it if it is a possibly unstable version that has not yet been fully tested. Other (stable) versions should hopefully have less show stopping bugs and less incomplete features, because they've been tested a little more on some platforms. Most testing of pyChing takes place on Linux, so if you run it on some other platform I'd particularly  like to know how it goes, or get any detailed bug reports. Contact details  are shown in the About box.  
 <h3>Help and Information Viewer</h3>
 <p>
-If you are viewing one of pyChing's help files, there will be an 'Index' button at the bottom of the dialog (which will be disabled if you are actually viewing the help index). Click on the 'Index' button to return to the 'Using pyChing - Help Index' page. In any of these help or information viewer windows, just click on 'Ok' when you've seen enough... I seriously doubt I needed to tell you that.  ;-)
+If you are viewing one of pyChing's help files, there will be an 'Index' button at the bottom of the dialog (which will be disabled if you are actually viewing the help index). Click on the 'Index' button to return to the 'Using pyChing - Help Index' page. In any of these help or information viewer windows, just click on 'Ok' when you've seen enough... (I seriously doubt I needed to tell you that.  ;-)
+<h3>Hexagram Information Browsing</h3>
+<p>
+The hexagram information browser lets you browse the available information for any hexagram you wish. Click on the 'Prev' or 'Next' buttons (if active) to browse info on the next or previous hexagram (in numbered sequence). To view information on a particular hexagram, click on 'Go To Number' and enter the number (from 1 to 64) of the hexagram you wish to view. The 'Quit' button, of course, quits the browser.
 <p></body></html>
 """
 
